@@ -54,7 +54,7 @@ fread <- function(input="",file=NULL,text=NULL,cmd=NULL,sep="auto",sep2="auto",d
       if (str7=="ftps://" || str8=="https://") {
         # nocov start
         if (!requireNamespace("curl", quietly = TRUE))
-          stop("Input URL requires https:// connection for which fread() requires 'curl' package, but cannot be found. Please install curl using 'install.packages('curl')'.")
+          stop("Input URL requires https:// connection for which fread() requires 'curl' package which cannot be found. Please install 'curl' using 'install.packages('curl')'.") # nocov
         curl::curl_download(input, tmpFile<-tempfile(), mode="wb", quiet = !showProgress)
         file = tmpFile
         on.exit(unlink(tmpFile), add=TRUE)
@@ -77,7 +77,18 @@ fread <- function(input="",file=NULL,text=NULL,cmd=NULL,sep="auto",sep2="auto",d
         }
       }
       else {
-        file = input
+        file = input   # filename
+        ext2 = substring(file, nchar(file)-2L, nchar(file))   # last 3 characters ".gz"
+        ext3 = substring(file, nchar(file)-3L, nchar(file))   # last 4 characters ".bz2"
+        if (ext2==".gz" || ext3==".bz2") {
+          if (!requireNamespace("R.utils", quietly = TRUE))
+            stop("To read gz and bz2 files directly, fread() requires 'R.utils' package which cannot be found. Please install 'R.utils' using 'install.packages('R.utils')'.") # nocov
+          if (ext2==".gz") { ext="gz";  FUN=gzfile; }
+          else             { ext="bz2"; FUN=bzfile; }
+          R.utils::decompressFile(file, tmpFile<-tempfile(), ext=ext, FUN=FUN, remove=FALSE)
+          file = tmpFile
+          on.exit(unlink(tmpFile), add=TRUE)
+        }
       }
     }
   }
