@@ -32,7 +32,7 @@ DF["C", ]
 ## ----eval = FALSE---------------------------------------------------------------------------------
 #  rownames(DF) = sample(LETTERS[1:5], 10, TRUE)
 #  # Warning: non-unique values when setting 'row.names': 'C', 'D'
-#  # Error in `row.names<-.data.frame`(`*tmp*`, value = value): duplicate 'row.names' are not allowed
+#  # Error in `.rowNamesDF<-`(x, value = value): duplicate 'row.names' are not allowed
 
 ## -------------------------------------------------------------------------------------------------
 DT = as.data.table(DF)
@@ -134,17 +134,20 @@ flights[.(c("LGA", "JFK", "EWR"), "XNA"), mult = "last", nomatch = 0L]
 ## ----eval = FALSE---------------------------------------------------------------------------------
 #  flights[origin == "JFK" & dest == "MIA"]
 
+## ----eval = FALSE---------------------------------------------------------------------------------
+#  setkey(flights, NULL)
+#  flights[origin == "JFK" & dest == "MIA"]
+
 ## -------------------------------------------------------------------------------------------------
 set.seed(2L)
 N = 2e7L
 DT = data.table(x = sample(letters, N, TRUE),
                 y = sample(1000L, N, TRUE),
-              val = runif(N), key = c("x", "y"))
+                val = runif(N))
 print(object.size(DT), units = "Mb")
 
-key(DT)
-
 ## -------------------------------------------------------------------------------------------------
+key(DT)
 ## (1) Usual way of subsetting - vector scan approach
 t1 <- system.time(ans1 <- DT[x == "g" & y == 877L])
 t1
@@ -152,6 +155,8 @@ head(ans1)
 dim(ans1)
 
 ## -------------------------------------------------------------------------------------------------
+setkeyv(DT, c("x", "y"))
+key(DT)
 ## (2) Subsetting using keys
 t2 <- system.time(ans2 <- DT[.("g", 877L)])
 t2
